#!/bin/bash

# Zenwalk build script for loudmouth
# Maintainer: Markus Muttilainen <stillborn~dot~zenwalk~at~gmail~dot~com>
# Packaging date: 19.07.2010
# url=http://groups.google.com/group/loudmouth-dev/web/Loudmouth%201.4.3
# source=http://ftp.gnome.org/pub/GNOME/sources/loudmouth/1.4/loudmouth-1.4.3.tar.bz2
#Log
(

PRGNAM=loudmouth
VERSION=1.4.3
BUILD=66.1
ARCH=i486 
CPU=i686
DS="2" #  0={none}  1={.dep}  2={.dep,slack-required}
CWD=`pwd`
TMP=${TMP:-/tmp/}
PKG=$TMP/package-$PRGNAM
OUTPUT=${OUTPUT:-$CWD/$PRGNAM}

set -e -x -u

### Getting sources do
#wget -c -r -nd -np --accept=bz2,gz http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/sources/ 

rm -rf $PKG $OUTPUT
mkdir -p $TMP $PKG $OUTPUT
cd $TMP
rm -rf $PRGNAM-$VERSION
tar xvf $CWD/$PRGNAM-$VERSION.tar.bz2
cd $PRGNAM-$VERSION
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

zcat $CWD/loudmouth.crtpath.diff.gz | patch -p1 --verbose || exit 1
zcat $CWD/loudmouth.gnutls.configure.ac.diff.gz | patch -p1 --verbose || exit 1
zcat $CWD/loudmouth.async_assertion.diff.gz | patch -p1 --verbose || exit 1
zcat $CWD/loudmouth.sasl-md5-digest-uri.diff.gz | patch -p1 --verbose || exit 1
zcat $CWD/loudmouth.stanzadrop.diff.gz | patch -p1 --verbose || exit 1

autoreconf -vif

export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
 ./configure \
  --prefix=/usr \
  --libdir=/usr/lib \
  --sysconfdir=/etc \
  --with-ssl=gnutls \
  --localstatedir=/var \
  --disable-static \
  --with-html-dir=/usr/doc/$PRGNAM-$VERSION \
  --build=$ARCH-slackware-linux \
  --host=$ARCH-slackware-linux

# this generates a broken libtool, so use the system version:
cp /usr/bin/libtool .

make
make install-strip DESTDIR=$PKG

# --disable-static is often ignored
rm -f $PKG/usr/lib/lib*.a

mkdir -p $PKG/install 
mkdir -p $PKG/usr/{src,doc}/$PRGNAM-$VERSION
cp -a AUTHORS ChangeLog CONTRIBUTORS COPYING INSTALL NEWS README* \
  $PKG/usr/doc/$PRGNAM-$VERSION
cat $CWD/build-$PRGNAM.sh > $PKG/usr/src/$PRGNAM-$VERSION/build-$PRGNAM.sh


### Slack-desc
#      |-----handy-ruler------------------------------------------------------|
cat > $PKG/install/slack-desc << EOF
$PRGNAM: $PRGNAM - (Jabber Protocol library)
$PRGNAM:
$PRGNAM: Loudmouth is a lightweight and easy-to-use C library for 
$PRGNAM: programming with the Jabber protocol. It's designed to be easy 
$PRGNAM: to get started with and yet extensible to let you do anything the 
$PRGNAM: Jabber protocol allows.
$PRGNAM:
$PRGNAM:
$PRGNAM:
$PRGNAM:
$PRGNAM: Homepage: http://www.loudmouth-project.org/
EOF

#> helperline
(cd $PKG;find . -printf "%y %m %u:%g %p %l\n") >$CWD/pkgtree.log

cd $PKG
/sbin/makepkg -l y -c n $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.txz
/bin/md5sum $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.txz > $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.md5
echo "http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/build-loudmouth.sh" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src
echo "http://ftp.gnome.org/pub/GNOME/sources/loudmouth/1.4/loudmouth-1.4.3.tar.bz2" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src
echo "http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/sources/loudmouth.crtpath.diff.gz" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src 
echo "http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/sources/loudmouth.gnutls.configure.ac.diff.gz" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src
echo "http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/sources/loudmouth.async_assertion.diff.gz" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src
echo "http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/sources/loudmouth.sasl-md5-digest-uri.diff.gz" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src
echo "http://zenwalk.pinguix.com/user-accounts/stillborn/loudmouth/sources/loudmouth.stanzadrop.diff.gz" >> $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD.src

#> generate {.dep,slack-required}
cd $OUTPUT
if [ "$DS" = "2" ]; then
      depfinder -sf $PRGNAM-$VERSION-$ARCH-$BUILD.txz
      sed "s/^\(.*\) >=.*/\1/" slack-required | \
      sed "s/^\(.*\) >=\(.*\)|\(.*\)/\1|\3/" | \
      tr "\n" "," | \
      sed "s/\(.*\),$/\1/" > $PRGNAM-$VERSION-$ARCH-$BUILD.dep
elif [ "$DS" = "1" ]; then
      depfinder $PRGNAM-$VERSION-$ARCH-$BUILD.txz > $PRGNAM-$VERSION-$ARCH-$BUILD.dep
fi

# log
) 2>&1 | tee loudmouth-build.log.txt
